@@ -284,6 +284,20 @@ closes
          (fd simple int)))
 */
 
+#if 0
+void debug_packet(UINT32 length, UINT8 *data)
+{
+  int i;
+
+  debug("------\n");
+  for (i = 0; i < length; i++) 
+    {
+      debug("%c", data[i]);
+    }
+  debug("\n------\n");
+}
+#endif
+
 static int do_read(struct abstract_read **r, UINT32 length, UINT8 *buffer)
 {
   CAST(fd_read, closure, *r);
@@ -297,6 +311,13 @@ static int do_read(struct abstract_read **r, UINT32 length, UINT8 *buffer)
   for (;;)
     {
       int res = read(closure->fd, buffer, length);
+#if 0
+      if (res>=0)
+	{
+	  debug("readfd=%i, length=%i\n", closure->fd, res);
+	  debug_packet(res, buffer);
+	}
+#endif
       if (!res)
 	{
 #if 0
@@ -429,6 +450,14 @@ static int do_write(struct abstract_write *w, UINT32 length, UINT8 *data)
 
 	int res = write(self->fd, data, length);
 
+#if 0
+	if (res>=0)
+	  {
+	    debug("writefd=%i, length=%i\n", self->fd, res);
+	    debug_packet(res, data);
+	  }
+#endif
+
 	if (res < 0)
 	{
 		switch(errno)
