@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: objtypes.h,v 1.2 1999/07/10 13:23:09 bazsi Exp $
+ * $Id: objtypes.h,v 1.3 1999/08/31 20:57:35 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -74,8 +74,16 @@ do {						\
 } while(0)
 
 /* Useful macros. */
+#ifndef MIN
 #define MIN(a, b) (((a)>(b)) ? (b) : (a))
+#endif
+
+#ifndef MAX
 #define MAX(a, b) (((a)<(b)) ? (b) : (a))
+#endif
+
+#ifndef SQR
 #define SQR(x) ((x)*(x))
+#endif
      
 #endif
