@@ -92,15 +92,15 @@ static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 
 		res = A_WRITE(w, item->packet->length, item->packet->data);
 		if (res >= 0) {
-			if (self->super.writable)
-				(*self->super.writable) = 1;
 			if (item->packet->length == res) {
 				self->queue_size--;
 				ol_queue_remove((struct ol_queue_node *) item);
 				ol_string_free(item->packet);
 				ol_space_free(item);
+				if (self->super.writable)
+					(*self->super.writable) = 1;
 			}
-			else {
+			else if (res != 0) {
 				struct ol_string *s;
 				s = item->packet;
 				item->packet = c_format("%s", s->length - res, s->data + res);
